@@ -13,8 +13,8 @@ class ArXivConverter(BaseConverter):
         """Parse URL path part to Python rep (str)."""
         try:
             return identifier.parse_arxiv_id(value)
-        except ValueError as e:
-            raise ValidationError('Not a valid arXiv ID') from e
+        except ValueError as ex:
+            raise ValidationError('Not a valid arXiv ID') from ex
 
     def to_url(self, value: str) -> str:
         """Cast Python rep (str) to URL path part."""
